@@ -1,6 +1,6 @@
 use std::future::Future;
 
-use crate::{Endpoint, Error, IntoResponse, Request, Result};
+use crate::{Endpoint, IntoResponse, Request, Result};
 
 /// Endpoint for the [`map_err`](super::EndpointExt::map_err) method.
 pub struct MapErr<E, F> {
@@ -16,14 +16,16 @@ impl<E, F> MapErr<E, F> {
 }
 
 #[async_trait::async_trait]
-impl<E, F, Fut, R> Endpoint for MapErr<E, F>
+impl<E, F, Fut, InErr, OutErr, R> Endpoint for MapErr<E, F>
 where
-    E: Endpoint<Output = Result<R>>,
-    F: Fn(Error) -> Fut + Send + Sync + 'static,
-    Fut: Future<Output = Error> + Send + 'static,
+    E: Endpoint<Output = Result<R, InErr>>,
+    InErr: IntoResponse,
+    OutErr: IntoResponse,
+    F: Fn(InErr) -> Fut + Send + Sync + 'static,
+    Fut: Future<Output = OutErr> + Send + 'static,
     R: IntoResponse,
 {
-    type Output = E::Output;
+    type Output = Result<R, OutErr>;
 
     async fn call(&self, req: Request) -> Self::Output {
         match self.inner.call(req).await {
